# Python Package Exercise

An exercise to create a Python package, build it, test it, distribute it, and use it. See [instructions](./instructions.md) for details.

# Usage

TBD

# 4 Functions

### 8 Ball Predictions

- Input = question for the 8 ball

Variations:

If the input is too long – “Your message it tooo long, I can’t handle it”

### Affirmations based on mood
Input = mood (i.e. happy or sad)

Variations:

Will give you a compliment / affirmation based on your mood

### MakeMeLaugh

Input = type of joke

Variations:

Knock knock, Yo momma, etc.

### Copypasta

Input = ouptut type (text or image)

Variations:

Text copypasta, image copypasta (image made up of characters / emojis in terminal)

